@@ -11,4 +11,6 @@ model = dict(
         dropout_rate=0.2,
         act_cfg=dict(type='HSwish'),
         loss=dict(type='CrossEntropyLoss', loss_weight=1.0),
+        init_cfg=dict(
+            type='Normal', layer='Linear', mean=0., std=0.01, bias=0.),
         topk=(1, 5)))
