@@ -1,3 +1,4 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import os.path as osp
 import pickle
 import shutil
@@ -98,7 +99,8 @@ def multi_gpu_test(model, data_loader, tmpdir=None, gpu_collect=False):
                            ' Since tmpdir will be deleted after testing,',
                            ' please make sure you specify an empty one.'))
         prog_bar = mmcv.ProgressBar(len(dataset))
-    time.sleep(2)  # This line can prevent deadlock problem in some cases.
+    time.sleep(2)
+    dist.barrier()
     for i, data in enumerate(data_loader):
         with torch.no_grad():
             result = model(return_loss=False, **data)
