@@ -1,12 +1,10 @@
 # Copyright (c) OpenMMLab. All rights reserved.
-from .eval_hooks import DistEvalHook, EvalHook
 from .eval_metrics import (calculate_confusion_matrix, f1_score, precision,
                            precision_recall_f1, recall, support)
 from .mean_ap import average_precision, mAP
 from .multilabel_eval_metrics import average_performance
 
 __all__ = [
-    'DistEvalHook', 'EvalHook', 'precision', 'recall', 'f1_score', 'support',
-    'average_precision', 'mAP', 'average_performance',
-    'calculate_confusion_matrix', 'precision_recall_f1'
+    'precision', 'recall', 'f1_score', 'support', 'average_precision', 'mAP',
+    'average_performance', 'calculate_confusion_matrix', 'precision_recall_f1'
 ]
