@@ -25,10 +25,14 @@ SAMPLERS = Registry('sampler')
 
 
 def build_dataset(cfg, default_args=None):
-    from .dataset_wrappers import (ConcatDataset, RepeatDataset,
-                                   ClassBalancedDataset, KFoldDataset)
+    from .dataset_wrappers import (ClassBalancedDataset, ConcatDataset,
+                                   KFoldDataset, RepeatDataset)
     if isinstance(cfg, (list, tuple)):
         dataset = ConcatDataset([build_dataset(c, default_args) for c in cfg])
+    elif cfg['type'] == 'ConcatDataset':
+        dataset = ConcatDataset(
+            [build_dataset(c, default_args) for c in cfg['datasets']],
+            separate_eval=cfg.get('separate_eval', True))
     elif cfg['type'] == 'RepeatDataset':
         dataset = RepeatDataset(
             build_dataset(cfg['dataset'], default_args), cfg['times'])
@@ -100,7 +104,8 @@ def build_dataloader(dataset,
         sampler = build_sampler(
             sampler_cfg,
             default_args=dict(
-                dataset=dataset, num_replicas=world_size, rank=rank))
+                dataset=dataset, num_replicas=world_size, rank=rank,
+                seed=seed))
     # Default sampler logic
     elif dist:
         sampler = build_sampler(
@@ -110,7 +115,8 @@ def build_dataloader(dataset,
                 num_replicas=world_size,
                 rank=rank,
                 shuffle=shuffle,
-                round_up=round_up))
+                round_up=round_up,
+                seed=seed))
     else:
         sampler = None
 
@@ -152,6 +158,7 @@ def worker_init_fn(worker_id, num_workers, rank, seed):
     worker_seed = num_workers * rank + worker_id + seed
     np.random.seed(worker_seed)
     random.seed(worker_seed)
+    torch.manual_seed(worker_seed)
 
 
 def build_sampler(cfg, default_args=None):
