@@ -3,5 +3,7 @@ from .augments import Augments
 from .cutmix import BatchCutMixLayer
 from .identity import Identity
 from .mixup import BatchMixupLayer
+from .resizemix import BatchResizeMixLayer
 
-__all__ = ['Augments', 'BatchCutMixLayer', 'Identity', 'BatchMixupLayer']
+__all__ = ('Augments', 'BatchCutMixLayer', 'Identity', 'BatchMixupLayer',
+           'BatchResizeMixLayer')
